      SUBROUTINE MAP_STEEL_BAINTT(KTEMP,SHEART,C,AC,JT,JTHIGH,JTLOW,
     & T10,T20,W,W1,R,JN)
C
C  M. Takahashi and H.K.D.H. Bhadeshia, PT Group, Dept. Materials Science
C  and Metallurgy, University of Cambridge, Cambridge, U.K.
C
C  Subroutine to calculate the C curve for the transformation from austenite 
C  to bainite using the carbon concentration given by the current value of C(1):
C  KTEMP  - an array containing values of the temperature (Kelvin).
C  SHEART - an array containing the corresponding time (seconds).
C
C  It also calculates values for: 
C  T20 = deltaT_M = temperature change (due to the magnetic component), caused  
C                   by unit concentration of substitutional solute, to the 
C                   temperature at which the free energy transformation from  
C                   austenite to ferrite (deltaG^gamma,alpha) is calculated.
C  T10 = deltaT_M - deltaT_NM = temperature change (due to the non-magnetic 
C                               component)...
C  W   = carbon-carbon interaction energy in austenite (J/mole)
C  JN  = number of temperature calculations actually performed.
C
C  Input parameters:
C  C   - an array of dimension 8, containing the steel composition in wt% of
C        C,Si,Mn,Ni,Mo,Cr and V, in that order. C(8) is used to calculate the 
C        wt% of Fe by differnce.
C  AC  - an array of dimension 8 which is used as workspace in MAP_STEEL_OMEGA
C  JT  - is the temperature interval at which the calculations are performed (K)
C  JTLOW  - lowest temperature at which calculations are performed.
C  JTHIGH - highest temperature at which calculations are performed.
C  W1     - carbon-carbon interaction energy in ferrite (J/mole).
C  R      - molar gas constant (J/mol/K).
C
C
      IMPLICIT NONE
      DOUBLE PRECISION KTEMP(100),SHEART(100),C(8),AC(8),T10,T20,W,W1,R 
      DOUBLE PRECISION A,AFE,AJ,A1,DIFFT,F,GMAX,H1,S1,X,XBAR
      DOUBLE PRECISION MAP_STEEL_ENERGY,MAP_STEEL_CG,MAP_STEEL_AFEG
      INTEGER JT,JTHIGH,JTLOW,JN
      INTEGER J,JDUM,IZERO
C
      J=0
      IZERO=0
C
      AC(1)=C(1)
      AC(2)=C(2)
      AC(3)=C(3)
      AC(4)=C(4)
      AC(5)=C(5)
      AC(6)=C(6)
      AC(7)=C(7)
C
      CALL MAP_STEEL_OMEGA(AC,W,XBAR,T10,T20,IZERO)
C     -------------------------------------
      DO 100 JDUM=JTLOW,JTHIGH,JT
         J=J+1
         KTEMP(J)=JDUM*1.0D+00
         IF (KTEMP(J) .GE. 1000.0) THEN
            H1=105525.0D+00
            S1=45.34521D+00
         ELSE
            H1=111918.0D+00
            S1=51.44D+00
         ENDIF
         F=MAP_STEEL_ENERGY(KTEMP(J),T10,T20)
         AJ=1.0D+00-DEXP(-W/(R*KTEMP(J)))
         A=MAP_STEEL_CG(AC(1),KTEMP(J),W,R)
         AFE=MAP_STEEL_AFEG(AC(1),AJ)
         CALL MAP_STEEL_GMAAX(A1,A,W1,F,R,KTEMP(J),X,AFE,H1,S1)
         GMAX=R*KTEMP(J)*(A1-A)
         CALL MAP_STEEL_TTTT(KTEMP(J),GMAX,SHEART(J),DIFFT,R)
  100 CONTINUE
      JN=J
C     -------------------------------------
      RETURN
      END

